reader
The function to use when reading the data file. It should
accept three arguments: data.file, filename and
variable.name (in that order). The function should read the
contents of the file filename, and save it into the workspace
under the name variable.name. The data.file argument
is just a relative file name and can be ignored.